summaryrefslogtreecommitdiffstats
path: root/librss/loader.h
diff options
context:
space:
mode:
Diffstat (limited to 'librss/loader.h')
-rw-r--r--librss/loader.h18
1 files changed, 11 insertions, 7 deletions
diff --git a/librss/loader.h b/librss/loader.h
index 8c4fcb4d..8eca6643 100644
--- a/librss/loader.h
+++ b/librss/loader.h
@@ -32,9 +32,10 @@ namespace RSS
* a new retrieval algorithm which can then be plugged into the RSS loader.
* @see Loader, FileRetriever, OutputRetriever
*/
- class DataRetriever : public QObject
+ class DataRetriever : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor.
@@ -88,6 +89,7 @@ namespace RSS
class LIBRSS_EXPORT FileRetriever : public DataRetriever
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor.
@@ -148,6 +150,7 @@ namespace RSS
class OutputRetriever : public DataRetriever
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor.
@@ -194,8 +197,8 @@ namespace RSS
*
* \code
* Loader *loader = Loader::create();
- * connect(loader, TQT_SIGNAL(loadingComplete(Loader *, Document, Status)),
- * this, TQT_SLOT(slotLoadingComplete(Loader *, Document, Status)));
+ * connect(loader, TQT_SIGNAL(loadingComplete(Loader *, Document, tqStatus)),
+ * this, TQT_SLOT(slotLoadingComplete(Loader *, Document, tqStatus)));
* loader->loadFrom("http://www.blah.org/foobar.rdf", new FileRetriever);
* \endcode
*
@@ -219,7 +222,7 @@ namespace RSS
* 'slotLoadingComplete' method might look like this:
*
* \code
* void MyClass::slotLoadingComplete(Loader *loader, Document doc, Status status)
* {
* // Note that Loader::~Loader() is private, so you cannot delete Loader instances.
* // You don't need to do that anyway since Loader instances delete themselves.
@@ -237,9 +240,10 @@ namespace RSS
* loadingComplete signal goes out of scope. This is e.g. the case if you
* intend to call getPixmap() on Document::image()!
*/
- class LIBRSS_EXPORT Loader : public QObject
+ class LIBRSS_EXPORT Loader : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
friend class someClassWhichDoesNotExist;
public:
/**
@@ -300,9 +304,9 @@ namespace RSS
* the case if you intend to call getPixmap() on Document::image()!
* @param status A status byte telling whether there were any problems
* while retrieving or parsing the data.
- * @see Document, Status
+ * @see Document, tqStatus
*/
- void loadingComplete(Loader *loader, Document doc, Status status);
+ void loadingComplete(Loader *loader, Document doc, tqStatus status);
private slots:
void slotRetrieverDone(const TQByteArray &data, bool success);
@@ -219,7 +222,7 @@ namespace RSS
*
* \code
- * void MyClass::slotLoadingComplete(Loader *loader, Document doc, Status status)
+ * void MyClass::slotLoadingComplete(Loader *loader, Document doc, tqStatus status)
* {
* // Note that Loader::~Loader() is private, so you cannot delete Loader instances.